aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/layout
diff options
context:
space:
mode:
authorAqa-Ib <[email protected]>2024-10-02 22:25:25 +0200
committerGitHub <[email protected]>2024-10-02 21:25:25 +0100
commitde68e065fe861d7ca01eca267df4c305bc6e73c2 (patch)
tree6ec00637fbb39c18cf3508aaf8a6167b577dd1fa /src/layout
parente2426942e5716a742ea353d2a1de7d7760fbbb41 (diff)
downloadHyprland-de68e065fe861d7ca01eca267df4c305bc6e73c2.tar.gz
Hyprland-de68e065fe861d7ca01eca267df4c305bc6e73c2.zip
layout: fix dragging a window into a group after e242694 (#7976)
Diffstat (limited to 'src/layout')
-rw-r--r--src/layout/IHyprLayout.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/layout/IHyprLayout.cpp b/src/layout/IHyprLayout.cpp
index 0fb78d02..4b5c9d4f 100644
--- a/src/layout/IHyprLayout.cpp
+++ b/src/layout/IHyprLayout.cpp
@@ -552,10 +552,10 @@ void IHyprLayout::changeWindowFloatingMode(PHLWINDOW pWindow) {
pWindow->m_vLastFloatingSize = PSAVEDSIZE;
// move to narnia because we don't wanna find our own node. onWindowCreatedTiling should apply the coords back.
pWindow->m_vPosition = Vector2D(-999999, -999999);
- onWindowCreatedTiling(pWindow);
+ onWindowCreated(pWindow);
pWindow->m_vRealPosition.setValue(PSAVEDPOS);
pWindow->m_vRealSize.setValue(PSAVEDSIZE);
@@ -552,10 +552,10 @@ void IHyprLayout::changeWindowFloatingMode(PHLWINDOW pWindow) {
pWindow->m_vLastFloatingSize = PSAVEDSIZE;
- // move to narnia because we don't wanna find our own node. onWindowCreatedTiling should apply the coords back.
+ // move to narnia because we don't wanna find our own node. onWindowCreated should apply the coords back.
pWindow->m_vPosition = Vector2D(-999999, -999999);